#
# spec file for package xfce4-notifyd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xfce4-notifyd
Version:        0.9.4
Release:        1.2
Summary:        Simple Notification Daemon for Xfce
License:        GPL-2.0-only
Group:          System/Daemons
URL:            https://docs.xfce.org/apps/notifyd/start
Source:         https://archive.xfce.org/src/apps/xfce4-notifyd/0.9/%{name}-%{version}.tar.bz2
Source1:        %{name}.xml
Source100:      %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE xfce4-notifyd-relax-x11-version.patch lower required X11 version to allow building for Leap which only has 1.6.5, which is enough, though
Patch0:         xfce4-notifyd-relax-x11-version.patch
BuildRequires:  gettext
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xfce4-dev-tools >= 4.18.1
BuildRequires:  pkgconfig(dbus-1) >= 1.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.68.0
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.68.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.68.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(libnotify) >= 0.7.0
BuildRequires:  pkgconfig(libsystemd) >= 245
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= 4.14.0
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.12.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.12.0
BuildRequires:  pkgconfig(libxfconf-0) >= 4.10.0
BuildRequires:  pkgconfig(sqlite3) >= 3.34
BuildRequires:  pkgconfig(systemd) >= 245
BuildRequires:  pkgconfig(x11) >= 1.6.5
Requires:       %{name}-branding
Requires:       libnotify-tools
Recommends:     %{name}-lang = %{version}-%{release}
Provides:       notification-daemon-xfce = %{version}-%{release}
Obsoletes:      notification-daemon-xfce < %{version}-%{release}

%description
Xfce4-notifyd is a simple, visually-appealing notification daemon for Xfce that
implements the Freedesktop.org Desktop Notifications Specification.

%package branding-upstream
Summary:        Upstream Branding of xfce4-notifyd
# BRAND: xfce4-notifyd.xml: Controls the appearance of notifications.
Group:          System/GUI/XFCE
Supplements:    (xfce4-notifyd and branding-upstream)
Conflicts:      xfce4-notifyd-branding = %{version}
Provides:       xfce4-notifyd-branding = %{version}-%{release}
BuildArch:      noarch

%description branding-upstream
This package provides the upstream look and feel for the Xfce Notification Daemon.

%lang_package

%prep
%autosetup -p1

%build
xdt-autogen
%configure \
    --with-helper-path-prefix=%{_libexecdir} \
    --enable-systemd \
    --enable-maintainer-mode
%make_build

%install
%make_install

install -D -p -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml/xfce4-notifyd.xml

%suse_update_desktop_file -i xfce4-notifyd-config
find %{buildroot} -type f -name "*.la" -delete -print

%find_lang %{name} %{?no_lang_C}

%files
%doc AUTHORS NEWS README.md TODO
%license COPYING
%{_bindir}/xfce4-notifyd-config
%{_datadir}/applications/xfce4-notifyd-config.desktop
%{_datadir}/icons/hicolor/*/apps/org.xfce.notification.*
%{_datadir}/icons/hicolor/scalable/status/org.xfce.notification.*
%{_datadir}/icons/hicolor/scalable/status/notification-*symbolic.svg
%dir %{_datadir}/themes/*
%dir %{_datadir}/themes/*/xfce-notify-4.0
%{_datadir}/themes/*/xfce-notify-4.0/gtk.css
%dir %{_libexecdir}/xfce4
%dir %{_libexecdir}/xfce4/notifyd
%{_libexecdir}/xfce4/notifyd/xfce4-notifyd
%{_libdir}/xfce4/panel/plugins/libnotification-plugin.so
%{_datadir}/dbus-1/services/org.xfce.xfce4-notifyd.N*.service
%{_datadir}/xfce4/panel/plugins/notification-plugin.desktop
%config %{_sysconfdir}/xdg/autostart/xfce4-notifyd.desktop
%{_prefix}/lib/systemd/user/xfce4-notifyd.service
%{_mandir}/man1/xfce4-notifyd-config.1%{?ext_man}

%files lang -f %{name}.lang
%license COPYING

%files branding-upstream
%license COPYING
%dir %{_sysconfdir}/xdg/xfce4
%dir %{_sysconfdir}/xdg/xfce4/xfconf
%dir %{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml
%config %{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml/xfce4-notifyd.xml

%changelog
* Sat Feb 10 2024 Manfred Hollstein <manfred.h@gmx.net>
- update to 0.9.4:
  * Clarify why the symbolic icons don't go in symbolic/status
  * Fix icons directory names
  * Fall back to monitor 0 if no primary monitor set
  * Add a fallback for drawing the unread notification emblem
  * Remove redundant icon embleming code
  * Fix opacity on notification hover
  * Translation Updates
* Thu Nov 16 2023 Marcus Meissner <meissner@suse.com>
- relax branding requires (remove -version-release), so we can use
  xfce4-branding-openSUSE based branding. (bsc#1217193 bsc#1216470)
* Wed Nov 15 2023 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut over systemd-mini.
* Sun Nov 12 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.3:
  * Make the DELETE with LIMIT/OFFSET query work
  * Make the text in the 'Clear log' dialog less crowded
  * Set a transient parent on the 'Clear log' dialog if possible
  * 'Clear log' dialog's initial focus should be on the 'Cancel'
    button
  * Drop required xdt-autogen version to 4.18.1
  * Simplify markup sanitizing code a little
  * Re-escape text in GMarkupParser text handler
  * Sanitize instead of validating body text markup
  * Translation Updates
* Tue Oct 24 2023 Manfred Hollstein <manfred.h@gmx.net>
- Add xfce4-notifyd-relax-x11-version.patch, see boo#1216516
- Add minimum version expected for package xdg-dev-tools.
* Mon Oct 23 2023 Andreas Stieger <andreas.stieger@gmx.de>
- fix all packaging warnings
* Mon Sep 25 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to 0.9.2:
  * (Hopefully) actually fix settings migration code
  * (Hopefully) fix enum setting migration code
- Add --enable-systemd when calling configure
* Wed Sep 20 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to 0.9.1:
  * Make the XDG autostart file attempt a systemd start first
  * Only include the SystemdService= line if systemd support is
    enabled
  * Clean up some conditionals in configure.ac
  * Go back to installing the XDG autostart file by default
  * Allow installing systemd service file even if systemd is not
    installed
* Tue Sep 19 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to 0.9.0:
  * Add missing sanity check
  * I18n: Update po/LINGUAS list
  * wayland: put windows on overlay layer, not top
  * Set window theme before placing window
  * Set initial window position before realizing windows
  * Avoid storing NULL app IDs in the app ID count hashtable
  * Simplify dbus/systemd service dir logic in configure.ac
  * Fix typos in README
  * Install D-Bus and systemd files under $prefix by default
  * Fix distcheck when run as non-root
  * Use pkg-config to find default systemd user unit directory
  * Change default systemd user path from /lib/... to /usr/lib/...
  * Change options for installing startup files
  * Add positioning options top-center and bottom-center
  * Simplify notification placement code
  * Stop using GtkCornerType; migrate setting to enum nick
  * Move log level settings from int to enum nick string
  * Move datetime format setting from int to enum nick string
  * Have a single entry point for setting migrations
  * Fix incorrect enum value for apps log level
  * Use registered enum types for config->enum mapping
  * Move enums to common, use glib-mkenums
  * Use new XDT feature macros
  * Don't log duplicate entries when updating an existing notification
  * Clean up logic in notify_notify()
  * Correctly update critical notifications while in DnD mode
  * Fix incorrect casts in GTree foreach functions
  * Remove expire/fade timeout source removal hacks
  * Missed a spot to reset fade/slide
  * Allow slideout when no fadeout
  * Only start fade timeout if no existing handle
  * Only start expiration timeout if no existing handle
  * Ensure timeout sources are removed in _window_dispose()
  * Move log dbus signal emissions to XfceNotifyDaemonLog
  * Remove expire and fade sources before emitting closed signal
  * Emit NotificationClosed when not showing notification
  * Consolidate the window movement code
  * Add option to show notifications on all monitors
  * Migrate the primary-monitor setting to a string-based enum
  * Translation Updates
* Tue Feb 28 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to 0.8.2:
  * Remove WM_TAKE_FOCUS from WM_PROTOCOLS for notification windows
  * Add pref to change what fields are shown in notifications
  * Fix a use-after-free with a notification's app ID
  * Fix plural forms missing from translatable strings
  * Fix weird formatting mistake in configure.ac
  * Remove support for xfce4-panel 4.12.
  * Reduce gettext requirement to 0.20.
  * Simplify notification placement code
  * Add assertion to ensure no window with new ID exists in the tree
  * Fix possible index out of bounds issue
  * Don't compare uints like char pointers
  * Support default actions
  * Add option to allow gauge notifications to ignore DnD
  * Don't move notifications on mouse-over
  * If urgency updated, start/stop expiration
  * Close all non-urgent notifications when DnD is activated
  * Add a missing $(AM_V_GEN)
  * Remove intltool in favor of plain gettext
  * Use pkg-config to find gdbus-codegen
  * Don't hide glib-genmarshal behind MAINTAINER_MODE
  * Use glib-compile-resources instead of xdt-csource
  * Don't require xdt-csource for dist tarball builds
  * Translation Updates
* Fri Feb 17 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to 0.8.1:
  * Set 1.5s timeouts for the log dbus proxy
  * Move log dbus server to its own object/file
  * Wrap queue item struct creation with a function
  * Improve old log migration error reporting
  * Delete old log file if it was empty
  * Clean up old log action parsing loop
  * Print a message if log db is busy or locked
  * Plug memleak when not sending log changed signal
  * Use GStrvBuilder instead of constructing one manually
  * Handle empty strings from DBus
  * Limit notification body to 2 lines in plugin menu
  * Remove old legacy support options from configure
  * Ensure gdbus-codegen doesn't generate too-new code
  * Clean up generate code and deprecate Quit method
  * Make all notification log access go through dbus
  * Drop old gtk 3.0 themes (3.20 themes are always used)
  * Clean up build system
  * Add hidden setting to restore override-redirect behavior
  * Remove ChangeLog make target
  * Markdownify and update the readme
  * Disconnect from GtkIconTheme::changed when plugin destroyed
  * Load main panel icon with _load_symbolic() variant
  * Restore log viewer's scrolled window shadow-type
  * Update icon when icon-theme changes
  * Fix incorrect signal handler connections in settings dialog
  * Translation Updates
* Sat Feb 11 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to 0.8.0:
  * Notification windows don't need to be override-redirect
  * Reposition notifications when workarea changes
  * Add setting to allow ignoring app-specified expire timeout
  * Add setting to never expire notifications
  * Update log viewer in settings when log changes on disk
  * Fix one more unnecessary full count of unread messages
  * Update log entry icons when marking all read
  * Remove unused var
  * Use new unread emblem for icons in log
  * Stop checking if there are unread notifications as often
  * Improve the panel icon when there are unread notifications
  * Make the log max size a little friendlier
  * Remove warning about high log size limit
  * Add ability to mark individual log entries read
  * Add emblem to icon of unread messages in log
  * Make migrating the old log file more robust
  * Remove bool returns from the log write functions
  * Improve unread handling
  * Make max-log-size option work again
  * Add missing finalize for 'delete all' sqlite statement
  * Implement progressive loading for log viewer
  * Move log viewer to its own widget/file
  * Add options for what to do when opening the plugin menu
  * Add option to only show unread notifications in plugin menu
  * Reduce some error-checking boilerplate
  * Glade-ify the plugin settings dialog
  * Queue writes to sqlite database
  * settings: don't bail if libnotify init fails
  * Fix deprecated unitless font-size in ZOMG-PONIES! theme
  * Rearrange settings dialog
  * Add ability to delete individual log entries
  * Update my copyright & email
  * Add timestamp formatting options
  * Clean up extraneous things in settings glade file
  * Add "Mark All Read" button to settings and panel plugin
  * Move notification log to sqlite
  * Set default debug based on git/not-git
  * Remove configure.ac from gitignore
  * Eliminate need for pre-processed configure.ac.in
  * Translation Updates
* Thu Feb  2 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to 0.7.3:
  * Add timestamp to log entries in settings and plugin menu
  * Update description text of apps panel in settings
  * Change text of option to "Allow urgent notifications"
  * Add panel plugin setting for log icon size in menu
  * Make it easier to add things to the panel plugin settings
  * Fix possible segfault when counting apps frequency in log
  * Clean and DRY up the log population code
  * Fix panel plugin menu icon blurriness when UI scale > 1
  * Update XfceNotifyDaemon header comment
  * Translation Updates
* Sun Jan 22 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to 0.7.2:
  * Fix sound proplist memleak when notification isn't shown
  * Improve sorting in known apps list of settings
  * Add extra margin in the known app settings
  * Fix word casing in known app settings
  * Add ability to exclude specific applications from log
  * Better, non-quadratic algo for xfce_notify_count_apps_in_log()
  * Plug memleak in notify_get_from_desktop_file()
  * Redesign the known apps panel a bit
  * Remove a few more GTK_CHECK_VERSION call sites
  * Avoid use-after-free when deleting known app
  * Improve algo for finding desktop file for known app name
  * Improve icon loading for known apps list
  * Don't set invalid icon name in known apps list
  * Translation Updates
* Sat Jan 21 2023 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 0.7.1:
  * Fix incorrect usage of XDT_CHECK_OPTIONAL_PACKAGE
  * Properly validate markup
  * Update glade file to remove use of deprecated properties
  * Support the 'action-icons' hint
  * Add support for notification sounds
  * Clean up notification ID storage
  * Return replaces_id if provided
  * Remove xfconf prop name define duplication
  * Add ability to disallow certain apps to send critical notifications
  * Add a context menu that allows individual known application deletion
  * Fix a slide-out loop when the mouse pointer is in the way
  * Add option to hide panel button when no unread notifications
  * Remove more pre-GTK-3.22 guards
  * Bump GTK minimum to 2.22 and remove/ifdef X11-isms
  * Support Wayland
  * Don't set a nonsensical icon name
  * Clean up xfce_notify_window_set_icon_pixbuf()
  * xfce_notify_window_set_icon_pixbuf() shouldn't take ownership
  * Move urgency hint fetch inside check for correct type
  * DRY up the configuration handling
  * Add pref to show summary & body with gauge values
  * Update glade file to latest version
  * settings: Disable single click to mute apps
    (gxo#apps/xfce4-notifyd#5)
  * Do not treat zero expiration time as urgent
  * Add compile_flags.txt generation
  * Fix incorrect icon name for preview notification
  * Fix blurry icons when UI scale factor > 1
  * build: Let xdt-depends.m4 macros set GLib macros
  * Translation Updates
* Sun Dec 18 2022 Dirk Müller <dmueller@suse.com>
- update to 0.6.5:
  * Fix segfault crash.
  * Translation Updates:
  Czech, Greek, Hebrew, Kazakh, Occitan (post 1500), Portuguese
* Sat Sep  3 2022 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 0.6.4
  - settings: Improve app icon and name matching
  - settings: Sort known apps by notification count
  - settings: Show 'Unspecified app' instead of empty line
  - daemon: Improve application icon matching
  - Correctly reset position during slideout (gxo#apps/xfce4-notifyd#42)
  - panel-plugin: Remove duplicate function call (gxo#apps/xfce4-notifyd#40)
  - panel-plugin: Fix file monitor (gxo#apps/xfce4-notifyd#40)
  - Properly free the GKeyFile
  - tests: Add logging test
  - Fix compiler warnings
  - Fix tooltip grammar
  - build: Fix intltool lock file problem during make distcheck
  - Update gitignore
  - Update COPYING (gxo#apps/xfce4-notifyd#61)
  - Translation Updates
* Tue Feb 15 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.6.3
  * Fix compilation warnings
  * autoconf: Some updates
  * Update `.gitignore`
  * Remove GSourceFunc casts
  * Fix missing-prototypes
  * Bump required GLib version to 2.56
  * Implement ISO 8601 time format to avoid post-2.56 GLib functions
  * settings: Drop subtitle
  * Fix multiple memory issues (gxo#apps/xfce4-notifyd!11)
  * Translation Updates
* Tue Sep  1 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 0.6.2
  * Switch to new app icon and rDNS icon name
  * Default to session autostart instead of DBus
    (gxo#apps/xfce4-notifyd#27)
  * Add configurable log size limit (default: 100)
  * Make buttons on non-1st notifications work
  * panel-plugin: Add option to hide "Clear log" dialog
  * log: properly handle iso8601 timestamps
  * log: Use SHA-1 data hash in icon cache paths (bxo#16825)
  * log: Improve performance of adding notifications (bxo#14865)
  * log: Refactor log keyfile element insertion into a separate function
  * Fix GTimeVal deprecation (bxo#16805)
  * Remove unused expire_timeout variable
  * Fix memory leaks
  * settings: Switch to symbolic close icon
  * Translation Updates
* Tue May  5 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 0.6.1
  * Fix hover effect without compositing (bxo#16586)
  * Move from exo-csource to xdt-csource (bxo#16717)
  * Translation Updates
* Wed Apr  8 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 0.6.0
  * Simplify drawing the notification bubble
  * Switch to new fallback style class "keycap"
  * Ensure normal font size with Adwaita and keycap class
  * Fix logging simultaneous notifications (bxo#15167)
  * Disable rounded corners w/o compositing (bxo#16586)
  * panel-plugin: Fix configure dialog
  * panel-plugin: Use new XfceTitledDialog api
  * panel-plugin: Toggle 'Do not disturb' with middle mouse click
    (bxo#16132)
  * Allow compilation with panel 4.15
  * panel-plugin: Remove deprecated calls
  * Replace GtkStock buttons
  * Translation Updates
* Tue Apr 23 2019 Vinzenz Vietzke <vinz@vinzv.de>
- This is a bugfix release:
  * Drop reference to dbus-binding-tool (bxo#14835)
  * Make more strings translatable (bxo#14890)
  * panel plugin: Fix menu position
  * panel-plugin: Fix first log entry not being shown (bxo#14920)
  * Fix Chrome notification icons (bxo#15215)
  * Fix output of xfce4-notifyd-config --help (bxo#14922)
  * Get rid of gdk_error_trap* deprecations
  * Add fallback for label alignment and older Gtk+3
  * Fix icon-size in the log toolbar
- Updated translations
- Spec file updated
* Wed Nov 21 2018 Stefan Seyfried <seife+obs@b1-systems.com>
- update to 0.4.3 (27 October 2018):
  This is (mostly) a translation update release.
  Bugs fixed:
  * Set the correct default value for fadeout (LP#1763674)
* Fri Mar  2 2018 seife+obs@b1-systems.com
- update to version 0.4.2 (01 March 2018):
  This is a bugfix release.
  Bugs fixed:
  * Fix support for hyperlinks in notifications (bxo#14073)
  * Fix crash because of double-free (bxo#14060)
  * Improve wrapping and ellipsizing of notification bubble
    (bxo#12674)
  * Ensure xfce4-notifyd.desktop.in goes into the tarball
    (bxo#13989)
  * Suppress warnings about unused and uninitialized variables
    (bxo#14095)
  * Fix crash when there are no known apps
  * panel-plugin: Fix showing placeholder when there are no logs
    from today
  * Updated translations
* Mon Dec 18 2017 seife+obs@b1-systems.com
- update to version 0.4.1 (09 December 2017):
  This is a feature release.
  Features:
  * Panel plugin features
  * Add hidden option log-icon-size
  * Add button to clear the log (bxo#13955)
  * Revamped layout (DND button on top for quick access)
  * Show placeholder text in case of empty logs
  * Improved notification window layout
  * Add configure option to use autostart instead of dbus (bxo#13989)
  Bugs fixed:
  * Remove deprecated functions (Gtk+ 3.22)
  * Fix warnings reported by Clang (Bug #13931)
  * Treat icon_data only as pen-ultimate fallback option (bxo#13950)
  * Fix warning about gdk_window_get_origin (bxo#13935)
  * Ensure body and summary of notifications are correctly
    ellipsized (bxo#12674)
  * Ensure the panel plugin icon resizes with Xfce 4.12
  * Updated translations
- removed obsolete xfce4-notifyd-0.4.0-fix-build-with-old-gtk3.diff
* Fri Nov 10 2017 seife+obs@b1-systems.com
- update to version 0.4.0 (07 October 2017):
  This is a feature release.
  Features:
  * Panel plugin that shows most recent notifications
    and allows for quick access to DND mode
  * Persistent daemon (bxo#12754)
  * New (optional) animation: slide-out
  * Support for all image types in the log
  * Better application icon matching in the config dialog
  * New logo (also in high resolution)
  Bugs fixed:
  * Bump notification spec version to 1.2 (bxo#13578)
  * Fix empty body when markup is invalid (bxo#10027)
  * Show warning in settings dialog if notifyd is not running (bxo#13417)
  * log-viewer: Fix escaping of characters and add markup support
  * Handle desktop-id as fallback in the log
  * Updated translations
- add xfce4-notifyd-0.4.0-fix-build-with-old-gtk3.diff (for Leap)
* Fri Apr 28 2017 tiwai@suse.de
- Fix the license to GPL-2.0 as xfce-notify-daemon.c is v2 only.
* Wed Apr 19 2017 seife+obs@b1-systems.com
- update to version 0.3.6:
  - Bugs fixed:
  * Fix memory leaks in log viewer (bxo#13400)
  * Fix a couple of memory leaks in notifyd-config (bxo#13386)
  * Update log toolbar buttons sensitivity (bxo#13365)
  - Updated translations
* Mon Feb 27 2017 seife+obs@b1-systems.com
- update to version 0.3.5:
  This is a feature release.
  - Features:
  * Notification log ("persistence" according to fd.o spec)
  * Rework settings dialog and include more options
  - Bugs fixed:
  * Fix height of settings dialog when plugged
  * Fix compilation on 3.14
  - Updated translations
* Sat Nov 26 2016 seife+obs@b1-systems.com
- update to version 0.3.4
  - port to GTK3 and gdbus
  - new "do not disturb" feature
  - various bugfixes and improvements; see NEWS file
  - do not package ChangeLog -- NEWS file is enough
* Wed May  8 2013 gber@opensuse.org
- update to version 0.2.4
  - fix border drawing when compositing is disabled
  - translation updates
* Sun Apr 21 2013 gber@opensuse.org
- update to version 0.2.3
  - add widget names to summary ("summary") and body ("body")
    widgets to allow easier theming; remove the redundant/buggy
    summary-bold style property
  - handle timeout correctly when smaller than fading time
  - parse body with g_markup_escape_text which allows us to handle
    span attributes misused by some clients and to parse strings
    with "unusual" characters such as &
  - respect border-width when drawing the notification
  - do not kill notification daemon to apply new theme, instead,
    handle style updates of existing notifications
  - show a button in the notification preview
  - add an icon to the notification preview
* Wed May 16 2012 gber@opensuse.org
- update to current git snapshot
  - show dialog in settings category
  - emit closed signal on correct object
  - avoid flickering of the window
  - fixup type setting
  - accept uri-image locations
* Sat Mar 31 2012 gber@opensuse.org
- split off -lang subpackage
- specfile cleanup
* Sat Aug  6 2011 gber@opensuse.org
- update to version 0.2.2
  - new cleaner settings dialog with preview on theme change
  - only initialize the close timeout when all notifications are
    closed
  - allow installation of the helpers in a custom location
  - bugfixes
  - translation updates
- dropped obsolete xfce4-notifyd-fix-dbus-service-filename.patch
* Sun May 29 2011 gber@opensuse.org
- added xfce4-notifyd-fix-dbus-service-filename.patch in order to
  make the filename of the DBus service file unique and prevent a
  conflict with notification-daemon
* Thu Feb 17 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
* Thu Feb  3 2011 gber@opensuse.org
- depend on libnotify rather than libnotify-tools for < 11.4
* Thu Feb  3 2011 gber@opensuse.org
- update to version 0.2.1
  - fade to transparent when screen is composited, remove the
    setting
  - bugfixes
  - translation updates
* Wed Jan  5 2011 gber@opensuse.org
- added -branding-upstream subpackage
- show compiler output
* Mon Dec 27 2010 gber@opensuse.org
- minor cleanup
- improved summary/group
* Sat Dec 25 2010 gber@opensuse.org
- use versioned obsoletion
* Tue Dec 21 2010 gber@opensuse.org
- xfce4-notifyd-config requires notify-send
* Wed Dec 15 2010 prusnak@opensuse.org
- fix filelist
* Thu Dec  2 2010 admin@djscore.org
- updated to new version 0.2.0
* Thu Aug 13 2009 puzel@novell.com
- update upstream URL
* Tue Nov 25 2008 prusnak@suse.cz
- created package (v 0.1.0)
